@@ -22,7 +22,7 @@ import copy
 import numpy as np
 
 from .agent import Agent
-from openenv.util.math import boltzmann_softmax
+import openenv.util.math.boltzmann_softmax as boltzmann_softmax
 
 class GviAgent(Agent):
     """Generialized value iteration.
